@@ -13,7 +13,7 @@ import tqdm
 from chromadb.api.models.AsyncCollection import AsyncCollection
 from chromadb.api.types import IncludeEnum
 
-from vectorcode.chunking import TreeSitterChunker
+from vectorcode.chunking import Chunk, TreeSitterChunker
 from vectorcode.cli_utils import Config, expand_globs, expand_path
 from vectorcode.common import get_client, get_collection, verify_ef
 
@@ -54,24 +54,30 @@ async def chunked_add(
 
     try:
         async with semaphore:
-            chunks = list(
-                TreeSitterChunker(configs.chunk_size, configs.overlap_ratio).chunk(
-                    full_path_str
-                )
+            chunks: list[Chunk | str] = list(
+                TreeSitterChunker(configs).chunk(full_path_str)
             )
             if len(chunks) == 0 or (len(chunks) == 1 and chunks[0] == ""):
                 # empty file
                 return
             chunks.append(str(os.path.relpath(full_path_str, configs.project_root)))
+            metas = []
+            for chunk in chunks:
+                meta: dict[str, str | dict[str, int]] = {"path": full_path_str}
+                if isinstance(chunk, Chunk):
+                    meta["start"] = chunk.start.row
+                    meta["end"] = chunk.end.row
+
+                metas.append(meta)
             async with collection_lock:
                 for idx in range(0, len(chunks), max_batch_size):
                     inserted_chunks = chunks[idx : idx + max_batch_size]
                     await collection.add(
                         ids=[get_uuid() for _ in inserted_chunks],
-                        documents=inserted_chunks,
-                        metadatas=[{"path": full_path_str} for _ in inserted_chunks],
+                        documents=[str(i) for i in inserted_chunks],
+                        metadatas=metas,
                     )
-    except UnicodeDecodeError:
+    except UnicodeDecodeError:  # pragma: nocover
         # probably binary. skip it.
         return
 
@@ -129,6 +135,7 @@ def load_files_from_include(project_root: str) -> list[str]:
 
 
 async def vectorise(configs: Config) -> int:
+    assert configs.project_root is not None
     client = await get_client(configs)
     try:
         collection = await get_collection(client, configs, True)
@@ -139,13 +146,23 @@ async def vectorise(configs: Config) -> int:
         return 1
     gitignore_path = os.path.join(str(configs.project_root), ".gitignore")
     files = await expand_globs(
-        configs.files or load_files_from_include(configs.project_root),
+        configs.files or load_files_from_include(str(configs.project_root)),
         recursive=configs.recursive,
     )
-    if os.path.isfile(gitignore_path) and not configs.force:
-        with open(gitignore_path) as fin:
-            gitignore_spec = pathspec.GitIgnoreSpec.from_lines(fin.readlines())
-        files = exclude_paths_by_spec((str(i) for i in files), gitignore_spec)
+    if not configs.force:
+        specs = [
+            gitignore_path,
+        ]
+        exclude_spec_path = os.path.join(
+            configs.project_root, ".vectorcode", "vectorcode.exclude"
+        )
+        if os.path.isfile(exclude_spec_path):
+            specs.append(exclude_spec_path)
+        for spec_path in specs:
+            if os.path.isfile(spec_path):
+                with open(spec_path) as fin:
+                    spec = pathspec.GitIgnoreSpec.from_lines(fin.readlines())
+                files = exclude_paths_by_spec((str(i) for i in files), spec)
 
     stats = {"add": 0, "update": 0, "removed": 0}
     collection_lock = Lock()
@@ -183,14 +200,14 @@ async def vectorise(configs: Config) -> int:
         all_results = await collection.get(include=[IncludeEnum.metadatas])
         if all_results is not None and all_results.get("metadatas"):
             paths = (meta["path"] for meta in all_results["metadatas"])
-            orphanes = set()
+            orphans = set()
             for path in paths:
                 if isinstance(path, str) and not os.path.isfile(path):
-                    orphanes.add(path)
+                    orphans.add(path)
             async with stats_lock:
-                stats["removed"] = len(orphanes)
-            if len(orphanes):
-                await collection.delete(where={"path": {"$in": list(orphanes)}})
+                stats["removed"] = len(orphans)
+            if len(orphans):
+                await collection.delete(where={"path": {"$in": list(orphans)}})
 
     show_stats(configs=configs, stats=stats)
     return 0
